API Usage — CKEditor Sample

# CKEditor Samples » Using CKEditor JavaScript API

This sample is not maintained anymore. Check out its brand new version in CKEditor SDK.

This sample shows how to use the CKEditor JavaScript API to interact with the editor at runtime.

For details on how to create this setup check the source code of this sample page.

<p>This is some <strong>sample text</strong>. You are using <a href="http://ckeditor.com/">CKEditor</a>.</p>

<h2>Test</h2><p>This is some <a href="/Test1.html">sample</a> HTML code.</p>
First line with some leading whitespaces. Second line of text preceded by two line breaks.